@@ -1,8 +1,8 @@
 package XFST::Lookup;
 
-# $Header: /var/cvsroot/XFST-Lookup/lib/XFST/Lookup.pm,v 1.11 2005/06/10 13:39:37 alex Exp $
+# $Header: /var/cvsroot/XFST-Lookup/lib/XFST/Lookup.pm,v 1.15 2005/06/14 20:03:14 alex Exp $
 
-$VERSION="0.4";
+$VERSION="0.5";
 
 use strict;
 use Carp;
@@ -227,6 +227,8 @@ sub lookup {
     my $opt = shift || croak "No options given!\n";
     
     my %results;
+
+    my %seen;   # remove until next version
     
     croak "Options not supplied via hashref!\n" unless ( ref($opt) eq 'HASH' );
     
@@ -313,8 +315,11 @@ sub lookup {
 
         # match the three fields ( 1x input, 2x parts analysis(base+tags) )
         $line =~ /^([$cclass]+)\s+([$cclass]+)\s+([$cclass]+)$/;
-        if( $1 && $2 && $3 ) {
-            push @{$results{$1}}, "$2$3";
+        if ( $1 && $2 && $3 ) {
+            unless( $seen{$1}->{"$2$3"} ) {
+                push @{$results{$1}}, "$2$3";
+                $seen{$1}->{"$2$3"} = 1;
+            }
         }
         else {
             carp "Error parsing line: '$line'\n";
